@@ -1,29 +1,25 @@
 from .context import DATADIR
-from model.common.commonmodel import CommonModel
+from pydantic import BaseModel
 from model.bcpnp.data import General
 from model.common.jobposition import PositionBase
 from model.common.wordmaker import WordMaker
 import os
+from model.common.commonmodel import CommonModel
 
 
 class Position(PositionBase):
     pass
 
 
-class CompanyInfoModel(CommonModel):
+class CompanyInfoModel(BaseModel):
     general: General
     position: Position
-    # initialize the model with a list of excels, which includes all nececcery information the model required. if outpuot_excel_file is not None, it will make an excel file.
+
+
+class CompanyInfoModel_E(CommonModel, CompanyInfoModel):
     def __init__(self, excels=None, output_excel_file=None):
-        if output_excel_file:
-            excels = self.getExcels(["excel/er.xlsx"])
-        else:
-            if excels is None and len(excels) == 0:
-                raise ValueError(
-                    "You must input excel file list as source data for validation"
-                )
-        # call parent class for validating
-        super().__init__(excels, output_excel_file, globals())
+        mother_excels = ["excel/er.xlsx"]
+        super().__init__(excels, output_excel_file, mother_excels, globals())
 
 
 class CompanyInfoDocxAdaptor:
