@@ -1,7 +1,7 @@
 from .context import DATADIR
 from typing import List
 
-from pydantic import EmailStr
+from pydantic import EmailStr, BaseModel
 from model.common.commonmodel import CommonModel
 from model.bcpnp.data import Bcpnp, General, JobOffer, ErAddress
 from model.common.jobposition import PositionBase
@@ -12,6 +12,7 @@ from model.common.address import Address, Addresses
 from model.common.phone import Phone, Phones
 from model.common.wordmaker import WordMaker
 import os
+from model.common.commonmodel import CommonModel, BuilderModel
 
 
 class Personal(Person):
@@ -25,7 +26,7 @@ class Position(PositionBase):
     pass
 
 
-class EmployeeTrainingModel(CommonModel):
+class EmployeeTrainingModel(BaseModel, BuilderModel):
     eraddress: List[ErAddress]
     general: General
     position: Position
@@ -39,26 +40,6 @@ class EmployeeTrainingModel(CommonModel):
     advertisement: List[Advertisement]
     recruitmentsummary: RecruitmentSummary
 
-    # initialize the model with a list of excels, which includes all nececcery information the model required. if outpuot_excel_file is not None, it will make an excel file.
-    def __init__(self, excels=None, output_excel_file=None):
-        if output_excel_file:
-            excels = self.getExcels(
-                [
-                    "excel/er.xlsx",
-                    "excel/pa.xlsx",
-                    "excel/recruitment.xlsx",
-                    "excel/bcpnp.xlsx",
-                    "excel/rep.xlsx",
-                ]
-            )
-        else:
-            if excels is None and len(excels) == 0:
-                raise ValueError(
-                    "You must input excel file list as source data for validation"
-                )
-        # call parent class for validating
-        super().__init__(excels, output_excel_file, globals())
-
     @property
     def residential_address(self):
         addresses = Addresses(self.address)
@@ -95,8 +76,8 @@ class EmployeeTrainingModel(CommonModel):
             "address": self.residential_address,
         }
 
-    def context(self,*args, **kwargs):
-        context= {
+    def context(self, *args, **kwargs):
+        context = {
             **self.dict(),
             "advertisement": self.advertisements,
             "personal": self.person,
@@ -106,31 +87,21 @@ class EmployeeTrainingModel(CommonModel):
             "work_location": self.work_location,
         }
         return context
-    
+
     def make_pdf_form(self, *args, **kwargs):
         pass
-    
+
     def make_web_form(self, *args, **kwargs):
         pass
 
-class EmployeeTrainingDocxAdaptor:
-    def __init__(self, employer_training_obj: EmployeeTrainingModel):
-        self.employer_training_obj = employer_training_obj
 
-    def re_generate_dict(self):
-        summary_info = {
-            "advertisement": self.employer_training_obj.advertisements,
-            "personal": self.employer_training_obj.person,
-            "date_of_offer": self.employer_training_obj.joboffer.date_of_offer,
-            "work_start_date": self.employer_training_obj.joboffer.start_date_say,
-            "joboffer_date": self.employer_training_obj.joboffer.date_of_offer,
-            "work_location": self.employer_training_obj.work_location,
-        }
-        return {**self.employer_training_obj.dict(), **summary_info}
-
-    def make(self, output_docx):
-        template_path = os.path.abspath(
-            os.path.join(DATADIR, "word/bcpnp_facts_brief_employee.docx")
-        )
-        wm = WordMaker(template_path, self.re_generate_dict(), output_docx)
-        wm.make()
+class EmployeeTrainingModelE(CommonModel, EmployeeTrainingModel):
+    def __init__(self, excels=None, output_excel_file=None):
+        mother_excels = [
+            "excel/er.xlsx",
+            "excel/pa.xlsx",
+            "excel/recruitment.xlsx",
+            "excel/bcpnp.xlsx",
+            "excel/rep.xlsx",
+        ]
+        super().__init__(excels, output_excel_file, mother_excels, globals())
