@@ -17,27 +17,10 @@ class Personal(BaseModel):
     uci: Optional[str]
 
 
-class M5476Model(CommonModel, BuilderModel):
+class M5476Model(BaseModel, BuilderModel):
     rciclist: List[RcicList]
     personal: Personal
 
-    # initialize the model with a list of excels, which includes all nececcery information the model required. if outpuot_excel_file is not None, it will make an excel file.
-    def __init__(self, excels=None, output_excel_file=None):
-        if output_excel_file:
-            excels = self.getExcels(
-                [
-                    "excel/pa.xlsx",
-                    "excel/rep.xlsx",
-                ]
-            )
-        else:
-            if excels is None and len(excels) == 0:
-                raise ValueError(
-                    "You must input excel file list as source data for validation"
-                )
-        # call parent class for validating
-        super().__init__(excels, output_excel_file, globals())
-
     def make_pdf_form(self, output_json, rcic_id_name, *args, **kwargs):
         pf = FormBuilder5476(self, rcic_id_name)
         form = pf.get_form()
@@ -50,3 +33,12 @@ class M5476Model(CommonModel, BuilderModel):
 
     def context(self, *args, **kwargs):
         raise ValueError("This model doesn't have webform...")
+
+
+class M5476ModelE(CommonModel, M5476Model):
+    def __init__(self, excels=None, output_excel_file=None):
+        mother_excels = [
+            "excel/pa.xlsx",
+            "excel/rep.xlsx",
+        ]
+        super().__init__(excels, output_excel_file, mother_excels, globals())
