@@ -14,7 +14,7 @@ class Status(BaseModel):
     current_status_end_date: date
     other_status_explaination: Optional[str]
     last_entry_date: Optional[date]
-    last_entry_place: Optional[date]
+    last_entry_place: Optional[str]
 
     @root_validator
     def checkWorkerType(cls, values):
