@@ -7,6 +7,7 @@ from model.common.utils import normalize, checkRow
 from pydantic.class_validators import root_validator
 from model.common.mixins import DatePeriod
 from model.data.city import canada_province
+import re
 
 
 class Personal(Person):
@@ -29,6 +30,12 @@ class Personal(Person):
         "used_last_name", allow_reuse=True, check_fields=False
     )(normalize)
 
+    @validator("uci")
+    def uci_check(cls, v):
+        if v and not re.match(r"^(\d{8}|\d{10})$", v):
+            raise ValueError("UCI must be a 8 digitals or 10 digitals")
+        return v
+
     @root_validator
     def checkAnswers(cls, values):
         questions = ["english_french"]
