@@ -13,9 +13,9 @@ def normalize(name: str):
 
 
 def makeList(name: str):
-    if name:
+    if name and not isinstance(name, list):
         return name.split("\n")
-    return []
+    return name if isinstance(name, list) else []
 
 
 def trimString(text: str):
@@ -106,7 +106,9 @@ def checkRow(values: dict, all_fields: List[str], required_fields: List[str]):
     has_values = [value for value in required_values if value]
 
     if any(all_fields_values) and not all(required_values):
-        missed_fields=[field for field in required_fields if values.get(field)==None]
+        missed_fields = [
+            field for field in required_fields if values.get(field) == None
+        ]
         raise ValueError(
             f"Please check the row with values ({has_values}), fileds {', '.join(missed_fields)} are missed."
         )
