@@ -15,7 +15,6 @@ from model.common.jobofferbase import JobofferBase
 from model.common.jobposition import PositionBase
 from termcolor import colored
 from model.common.utils import makeList
-import os
 
 
 class LmiaCase(BaseModel):
@@ -26,7 +25,7 @@ class LmiaCase(BaseModel):
     noc_outlook: int
     reason_failed_hire_canadian: Optional[str]
     provincial_median_wage: float
-    is_in_10_days_priority: bool
+    is_in_10_days_priority: Optional[bool]
     top10_wages: float
     is_waived_from_advertisement: bool
     reason_for_waived: Optional[str]
@@ -43,6 +42,10 @@ class LmiaCase(BaseModel):
     reason_not_use_jobbank: Optional[str]
     provide_details_even_waived: Optional[str]
 
+    @property
+    def duration(self):
+        return f"{self.duration_number} {self.duration_unit}"
+
     @root_validator
     def checkAdditional(cls, values):
         has_another_employer = values.get("has_another_employer", None)
@@ -89,10 +92,45 @@ class General(BaseModel):
     operating_name: Optional[str]
     website: Optional[str]
     establish_date: date
+    company_intro: str
     business_intro: str
     cra_number: str
     ft_employee_number: int
     pt_employee_number: int
+    has_lmia_approved: bool
+    when_lmia_approved: Optional[date]
+    lmia_num: Optional[str]
+    recruit_email: EmailStr
+
+    @root_validator
+    def checkHasApprovedLmia(cls, values):
+        has_lmia_approved = values.get("has_lmia_approved", None)
+        when_lmia_approved = values.get("when_lmia_approved", None)
+        lmia_num = values.get("lmia_num", None)
+        if has_lmia_approved and not (when_lmia_approved or lmia_num):
+            raise ValueError(
+                "Since has LMIA approved, but no when it got approved or no LMIA number."
+            )
+        return values
+
+    @property
+    def within_2years(self):
+        the_day = date.today()
+        if self.when_lmia_approved:
+            try:
+                years = (
+                    the_day.year
+                    - self.when_lmia_approved.year
+                    - (
+                        (the_day.month, the_day.day)
+                        < (self.when_lmia_approved.month, self.when_lmia_approved.day)
+                    )
+                )
+                return True if years <= 2 else False
+
+            except (ValueError, TypeError) as err:
+                print(err.args[0], " in file ", __file__)
+        return False
 
 
 class Lmi(BaseModel):
@@ -264,7 +302,7 @@ class Joboffer(JobofferBase):
     supervisor_title: str
     employer_rep: str
     employer_rep_title: str
-    vacation_pay_weeks: int
+    vacation_pay_days: int
     vacation_pay_percentage: float
     duties_brief: str
     duties: list
