@@ -18,7 +18,7 @@ class LmiaCase(BaseModel):
     noc_outlook: int
     reason_failed_hire_canadian: Optional[str]
     provincial_median_wage: float
-    is_in_10_days_priority: bool
+    is_in_10_days_priority: Optional[bool]
     top10_wages: float
     is_waived_from_advertisement: bool
     purpose_of_lmia: str
@@ -128,24 +128,21 @@ class Lmi(BaseModel):
         return values
 
 
-class LmiaRcic(CommonModel):
+class LmiaRcic(BaseModel):
     lmiacase: LmiaCase
     position: Position
     joboffer: Joboffer
     lmi: Lmi
     personalassess: PersonalAssess
 
-    # initialize the model with a list of excels, which includes all nececcery information the model required. if outpuot_excel_file is not None, it will make an excel file.
-    def __init__(self, excels=None, output_excel_file=None):
-        if output_excel_file:
-            excels = self.getExcels(
-                ["excel/er.xlsx", "excel/lmia.xlsx", "excel/pa.xlsx"]
-            )
 
-        else:
-            if excels is None and len(excels) == 0:
-                raise ValueError(
-                    "You must input excel file list as source data for validation"
-                )
-        # call parent class for validating
-        super().__init__(excels, output_excel_file, globals())
+class LmiaRcicE(CommonModel, LmiaRcic):
+    lmiacase: LmiaCase
+    position: Position
+    joboffer: Joboffer
+    lmi: Lmi
+    personalassess: PersonalAssess
+
+    def __init__(self, excels=None, output_excel_file=None):
+        mother_excels = ["excel/er.xlsx", "excel/lmia.xlsx", "excel/pa.xlsx"]
+        super().__init__(excels, output_excel_file, mother_excels, globals())
