@@ -177,10 +177,10 @@ class Personal(BaseModel):
     def checkAnswers(cls, values):
         questions = values.get("english_french")
         explanations = values.get("which_one_better")
-        if questions=="Both" and not explanations:
+        if questions == "Both" and not explanations:
             raise ValueError(
-                    f"Since you indicated both for English and French, but you did not indicate which one is better in info-personal sheet"
-                )
+                f"Since you indicated both for English and French, but you did not indicate which one is better in info-personal sheet"
+            )
         return values
 
     @root_validator
@@ -217,7 +217,7 @@ class Education(EducationBase):
     country: Optional[str]
 
 
-class M0008Model(CommonModel):
+class M0008Model(BaseModel):
     personal: Personal
     status: Status
     cor: List[COR]
@@ -228,13 +228,8 @@ class M0008Model(CommonModel):
     education: List[Education]
     prcase: PRCase
 
-    # initialize the model with a list of excels, which includes all nececcery information the model required. if outpuot_excel_file is not None, it will make an excel file.
+
+class M0008ModelE(CommonModel, M0008Model):
     def __init__(self, excels=None, output_excel_file=None):
-        if output_excel_file:
-            excels = self.getExcels(["excel/pr.xlsx", "excel/pa.xlsx"])
-        else:
-            if excels is None and len(excels) == 0:
-                raise ValueError(
-                    "You must input excel file list as source data for validation"
-                )
-        super().__init__(excels, output_excel_file, globals())
+        mother_excels = ["excel/pr.xlsx", "excel/pa.xlsx"]
+        super().__init__(excels, output_excel_file, mother_excels, globals())
