@@ -1,4 +1,4 @@
-from model.common.commonmodel import CommonModel
+from model.common.commonmodel import CommonModel, BuilderModel
 from datetime import date
 from pydantic import BaseModel, root_validator
 from typing import List
@@ -24,17 +24,12 @@ class Personal(BaseModel):
     first_name: str
 
 
-class M5562Model(CommonModel):
+class M5562Model(BaseModel):
     travel: List[Travel]
     personal: Personal
 
-    # initialize the model with a list of excels, which includes all nececcery information the model required. if outpuot_excel_file is not None, it will make an excel file.
+
+class M5562ModelE(CommonModel, M5562Model):
     def __init__(self, excels=None, output_excel_file=None):
-        if output_excel_file:
-            excels = self.getExcels(["excel/pa.xlsx"])
-        else:
-            if excels is None and len(excels) == 0:
-                raise ValueError(
-                    "You must input excel file list as source data for validation"
-                )
-        super().__init__(excels, output_excel_file, globals())
+        mother_excels = ["excel/pa.xlsx"]
+        super().__init__(excels, output_excel_file, mother_excels, globals())
