@@ -132,7 +132,7 @@ class AddressHistory(DatePeriod):
         return "table-addresshistory"
 
 
-class M5669Model(CommonModel):
+class M5669Model(BaseModel):
     personal: Personal
     family: List[Family]
     prbackground: PRBackground
@@ -143,18 +143,28 @@ class M5669Model(CommonModel):
     military: List[Military]
     addresshistory: List[AddressHistory]
 
-    # initialize the model with a list of excels, which includes all nececcery information the model required. if outpuot_excel_file is not None, it will make an excel file.
-    def __init__(self, excels=None, output_excel_file=None, check=False):
-        if output_excel_file:
-            excels = self.getExcels(["excel/pr.xlsx", "excel/pa.xlsx"])
-        else:
-            if excels is None and len(excels) == 0:
-                raise ValueError(
-                    "You must input excel file list as source data for validation"
+    def check(self, items: List[object]):
+        results = []
+        # construct list suitable for checkContinuity
+        for item in items:
+            results.append(list(item.__dict__.values()))
+
+        # check
+        continued, sorted_list, msg = checkContinuity(results)
+
+        if not continued:
+            print(
+                colored(
+                    f"There are {len(msg)} error(s) in sheet {items[0].__str__}", "red"
                 )
+            )
+            [print(index, "\t", m) for index, m in enumerate(msg)]
 
-        super().__init__(excels, output_excel_file, globals())
 
+class M5669ModelE(CommonModel, M5669Model):
+    def __init__(self, excels=None, output_excel_file=None, check=False):
+        mother_excels = ["excel/pr.xlsx", "excel/pa.xlsx"]
+        super().__init__(excels, output_excel_file, mother_excels, globals())
         if check:
             [self.check(item) for item in [self.history, self.addresshistory]]
 
