@@ -143,13 +143,19 @@ class TrCommon:
             self.form.add_radio(True)
             self.form.add_text(marriage.pre_sp_last_name)
             self.form.add_text(marriage.pre_sp_first_name)
+            if not marriage.pre_sp_dob:
+                raise ValueError("Previous spouse dob is None")
+            dob_list = marriage.pre_sp_dob.strftime("%Y-%m-%d").split("-")
+            if form_type == "1295":
+                self.form.add_text(dob_list, pause=0.1)
             self.form.add_dropdown(
                 marriage.pre_relationship_type, option_lists.relation_type
             )
             self.form.add_date(marriage.pre_start_date)
             self.form.add_date(marriage.pre_end_date)
             # speciaially dealing with
-            self.special_YMD_handle(marriage.pre_sp_dob)
+            if form_type != "1295":
+                self.special_YMD_handle(marriage.pre_sp_dob)
 
         else:
             self.form.add_radio(False)
