@@ -8,6 +8,7 @@ from source.infosheet import SheetDict
 from source.tablesheet import TableList
 import warnings
 from source.excelwriter import ExcelWritter
+from utils.utils import DateEncoder
 
 warnings.filterwarnings("ignore", category=UserWarning, module="openpyxl")
 
@@ -256,7 +257,8 @@ class Excel(object):
 
     @property
     def json(self):
-        print(json.dumps(self.dict, indent=3, default=str))
+        return  json.dumps(self.dict, indent=4, cls=DateEncoder)
+
 
     """
     Below is write back to excel  mothods
