@@ -403,6 +403,8 @@ validation = {
     "info-general": {
         "ft_employee_number": positive_int_include_zero,
         "pt_employee_number": positive_int_include_zero,
+        "canadian_ft_employee_num": positive_int_include_zero,
+        "canadian_pt_employee_num": positive_int_include_zero,
         "establish_date": date_format,
         "has_lmia_approved": yes_no,
         "corporate_structure": corporate_structure,
@@ -474,8 +476,8 @@ validation = {
         "oral": english_or_french,
         "writing": english_or_french,
         "offer_date": date_format,
-        "vacation_pay_weeks": positive_int_decimal,
-        "vacation_pay_percentage": positive_int_decimal,
+        "vacation_pay_days": positive_int_decimal,
+        "vacation_pay_percentage": positive_int,
         "education_level": education_level,
         "is_trade": yes_no,
         "trade_type": trade_education_type,
@@ -515,7 +517,7 @@ validation = {
     },
     "table-emp5624lmbp": {"start_date": date_format, "end_date": date_format},
     "info-emp5626": {
-        "is_seasonal": yes_no,
+        "is_in_seasonal_industry": yes_no,
         "start_month": months,
         "end_month": months,
         "last_canadian_number": positive_int,
@@ -525,6 +527,7 @@ validation = {
         "tp_waivable": yes_no,
         "has_finished_tp": yes_no,
         "waive_creteria": waive_creteria,
+        "named": yes_no,
     },
     "info-emp5627": {
         "named": yes_no,
@@ -539,6 +542,15 @@ validation = {
         "cap_exempted": yes_no,
         "which_exemption": cap_exemption_type,
     },
+    "table-captfw": {
+        "is_working": yes_no,
+        "designated_position": yes_no,
+        "pr_support_only_lmia": yes_no,
+        "in_application": yes_no,
+        "pr_in_process": yes_no,
+        "hourly_rate": positive_int_decimal,
+        "hours_per_week": positive_int_decimal,
+    },
     # PA
     "info-personal": {
         "sex": sex,
@@ -765,6 +777,8 @@ validation = {
     "info-wp": {
         "work_province": canada_provinces,
         "work_permit_type": wp_apply_wp_type,
+        "dual_intent": yes_no,
+        "refused_case": yes_no,
         "start_date": date_format,
         "end_date": date_format,
     },
