@@ -7,6 +7,8 @@ from termcolor import colored
 from tabulate import tabulate
 from typing import Union, List
 from rich.table import Table
+from json import JSONEncoder
+from datetime import date,datetime
 
 # This function used to check a list's continuity of date. The list must have two columns as start date and end date.
 # The fromat must be "yyyy-mm-dd" or "yyy-mm".  The list has to be from most recent to past. You can force sort it by assign sort =True
@@ -110,7 +112,7 @@ def best_match(term, list_names, min_score=0, return_score=False):
         return max_name
 
 
-def append_ext(filename: Union[str, List[str]], ext):
+def append_ext(filename: str | List[str], ext):
     def convert(fn):
         names = fn.split(".")
         if len(names) == 2:
@@ -274,6 +276,12 @@ def makeTable(table_name, table_list: list):
     return table
 
 
+class DateEncoder(JSONEncoder):
+        #Override the default method
+        def default(self, obj):
+            if isinstance(obj, (date)):
+                return obj.strftime("%Y-%m-%d")
+
 def main():
     # print(append_ext("a.docx", ".xlsx"))
     print(formatMoney(9211223213.22))
