@@ -1,10 +1,10 @@
 from audioop import add
 from datetime import datetime
-from webform.models.definition import Action, Role
-from webform.models.prmodel import PrModel
+from webform.definition import Action, Role
+from webform.prportal.prmodel import PrModel
 from model.common.address import Addresses
 from typing import List
-from webform.models.prmodel import Family
+from webform.prportal.prmodel import Family
 
 
 class F5669:
@@ -49,7 +49,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Go to Imm5669 ",
                 "actions": [],
-                "next_page_tag":"body > pra-root > pra-localized-app > main > div > pra-imm5669 > pra-imm5669-start > pra-family-table > button",
+                "next_page_tag": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > pra-imm5669-start > pra-family-table > button",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-intake-landing-page > pra-web-form-table > div > table > tbody > tr:nth-child(25) > td:nth-child(5) > button",
             }
         ]
@@ -60,7 +60,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Add new family member",
                 "actions": [],
-                "next_page_tag":"#sectionAFormMotherCountryOfBirth",
+                "next_page_tag": "#sectionAFormMotherCountryOfBirth",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > pra-imm5669-start > pra-family-table > button",
             }
         ]
@@ -127,7 +127,9 @@ class F5669:
             {
                 "action_type": "Input",
                 "label": "Family name",
-                "value": family_member.last_name+"  "+family_member.native_last_name,
+                "value": family_member.last_name
+                + "  "
+                + family_member.native_last_name,
                 "id": F5669.fild_id[relationship]["last_name"],
                 "length": 57,
                 "required": True,
@@ -135,7 +137,9 @@ class F5669:
             {
                 "action_type": "Input",
                 "label": "Given name",
-                "value": family_member.first_name+"  "+family_member.native_first_name,
+                "value": family_member.first_name
+                + "  "
+                + family_member.native_first_name,
                 "id": F5669.fild_id[relationship]["first_name"],
                 "length": 57,
                 "required": True,
@@ -312,7 +316,8 @@ class F5669:
         # loop each educaton
         value = []
         for index, edu in enumerate(person.education):
-            if edu.end_date=='Present':edu.end_date=None
+            if edu.end_date == "Present":
+                edu.end_date = None
             block = [
                 {
                     "action_type": Action.Input.value,
@@ -782,7 +787,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Section A: Personal details",
                 "actions": actions,
-                "next_page_tag":"#isPhysicalOrMentalDisorder_no",
+                "next_page_tag": "#isPhysicalOrMentalDisorder_no",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > lib-navigation-buttons > div > button.btn.btn-primary",
             }
         ]
@@ -794,7 +799,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Section B: Questionarie",
                 "actions": actions,
-                "next_page_tag":"#fieldOfStudy0",
+                "next_page_tag": "#fieldOfStudy0",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > lib-navigation-buttons > div > button.btn.btn-primary",
             }
         ]
@@ -806,7 +811,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Section C: Education",
                 "actions": actions,
-                "next_page_tag":"#nameOfEmployerOrSchool0",
+                "next_page_tag": "#nameOfEmployerOrSchool0",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > lib-navigation-buttons > div > button.btn.btn-primary",
             }
         ]
@@ -818,7 +823,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Section D: Personal history",
                 "actions": actions,
-                "next_page_tag":"#activities0",
+                "next_page_tag": "#activities0",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > lib-navigation-buttons > div > button.btn.btn-primary",
             }
         ]
@@ -830,7 +835,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Section E: Membership and association with organization",
                 "actions": actions,
-                "next_page_tag":"#department0",
+                "next_page_tag": "#department0",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > lib-navigation-buttons > div > button.btn.btn-primary",
             }
         ]
@@ -842,7 +847,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Section F: Government positions",
                 "actions": actions,
-                "next_page_tag":"#combatDetails0",
+                "next_page_tag": "#combatDetails0",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > lib-navigation-buttons > div > button.btn.btn-primary",
             }
         ]
@@ -854,7 +859,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Section G: Military and paramilitary service",
                 "actions": actions,
-                "next_page_tag":"#postalCode0",
+                "next_page_tag": "#postalCode0",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > lib-navigation-buttons > div > button.btn.btn-primary",
             }
         ]
@@ -866,7 +871,7 @@ class F5669:
                 "action_type": "WebPage",
                 "page_name": "Section H: Addresses",
                 "actions": actions,
-                "next_page_tag":"body > pra-root > pra-localized-app > main > div > pra-imm5669 > pra-imm5669-start > pra-family-table > button",
+                "next_page_tag": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > pra-imm5669-start > pra-family-table > button",
                 "id": "body > pra-root > pra-localized-app > main > div > pra-imm5669 > lib-navigation-buttons > div > button.btn.btn-primary",
             }
         ]
